@@ -36,14 +36,41 @@
 #'
 #' @examples
 #' library(dplyr, warn.conflicts = FALSE)
-#' library(admiral.test)
-#' data(admiral_ae)
-#' data(admiral_adsl)
+#' adsl <- tribble(
+#'   ~STUDYID,   ~USUBJID,      ~TRTSDT,      ~TRTEDT,
+#'   "PILOT01", "01-1307",           NA,           NA,
+#'   "PILOT01", "05-1377", "2014-01-04", "2014-01-25",
+#'   "PILOT01", "06-1384", "2012-09-15", "2012-09-24",
+#'   "PILOT01", "15-1085", "2013-02-16", "2013-08-18",
+#'   "PILOT01", "16-1298", "2013-04-08", "2013-06-28"
+#' ) %>%
+#'   mutate(
+#'     across(TRTSDT:TRTEDT, as.Date)
+#'   )
 #'
-#' adae <-
-#'   select(admiral_ae[sample(1:nrow(admiral_ae), 1000), ], USUBJID, AESTDTC, AEENDTC) %>%
+#' ae <- tribble(
+#'   ~STUDYID,  ~DOMAIN,  ~USUBJID,     ~AESTDTC,     ~AEENDTC,
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "16-1298", "2013-06-08", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-06-08", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06"
+#' )
+#'
+#' adae <- ae %>%
 #'   derive_vars_merged(
-#'     dataset_add = admiral_adsl,
+#'     dataset_add = adsl,
 #'     new_vars = exprs(TRTSDT, TRTEDT),
 #'     by_vars = exprs(USUBJID)
 #'   )
@@ -90,7 +117,7 @@ call_derivation <- function(dataset = NULL, derivation, variable_params, ...) {
     abort("All arguments inside `...` must be named")
   }
 
-  all_params <- base::union(unlist(map(variable_params, names)), names(fixed_params))
+  all_params <- union(unlist(map(variable_params, names)), names(fixed_params))
   assert_function_param(deparse(substitute(derivation)), all_params)
 
   for (i in seq_along(variable_params)) {
@@ -121,14 +148,43 @@ call_derivation <- function(dataset = NULL, derivation, variable_params, ...) {
 #'
 #' @examples
 #' library(dplyr, warn.conflicts = FALSE)
-#' library(admiral.test)
-#' data(admiral_ae)
-#' data(admiral_adsl)
 #'
-#' adae <- admiral_ae[sample(1:nrow(admiral_ae), 1000), ] %>%
+#' adsl <- tribble(
+#'   ~STUDYID,   ~USUBJID,      ~TRTSDT,      ~TRTEDT,
+#'   "PILOT01", "01-1307",           NA,           NA,
+#'   "PILOT01", "05-1377", "2014-01-04", "2014-01-25",
+#'   "PILOT01", "06-1384", "2012-09-15", "2012-09-24",
+#'   "PILOT01", "15-1085", "2013-02-16", "2013-08-18",
+#'   "PILOT01", "16-1298", "2013-04-08", "2013-06-28"
+#' ) %>%
+#'   mutate(
+#'     across(TRTSDT:TRTEDT, as.Date)
+#'   )
+#'
+#' ae <- tribble(
+#'   ~STUDYID,  ~DOMAIN,  ~USUBJID,     ~AESTDTC,     ~AEENDTC,
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-15", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "06-1384", "2012-09-23", "2012-09-29",
+#'   "PILOT01",    "AE", "16-1298", "2013-06-08", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-06-08", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06",
+#'   "PILOT01",    "AE", "16-1298", "2013-04-22", "2013-07-06"
+#' )
+#'
+#' adae <- ae %>%
 #'   select(USUBJID, AESTDTC, AEENDTC) %>%
 #'   derive_vars_merged(
-#'     dataset_add = admiral_adsl,
+#'     dataset_add = adsl,
 #'     new_vars = exprs(TRTSDT, TRTEDT),
 #'     by_vars = exprs(USUBJID)
 #'   )
@@ -150,6 +206,7 @@ call_derivation <- function(dataset = NULL, derivation, variable_params, ...) {
 #'     max_dates = exprs(TRTEDT)
 #'   )
 #'
+#'
 #' ## While `derive_vars_dt()` can only add one variable at a time, using `call_derivation()`
 #' ## one can add multiple variables in one go.
 #' ## The function arguments which are different from a variable to another (e.g. `new_vars_prefix`,
