@@ -36,8 +36,8 @@ get_duplicates_dataset <- function() {
 #' Extract Duplicate Records
 #'
 #' @param dataset A data frame
-#' @param by_vars A list of variables created using `exprs()` identifying groups of
-#'   records in which to look for duplicates
+#' @param by_vars A list of expressions created using `exprs()` identifying
+#'   groups of records in which to look for duplicates
 #'
 #' @return A `data.frame` of duplicate records within `dataset`
 #'
@@ -54,18 +54,24 @@ get_duplicates_dataset <- function() {
 #'
 #' extract_duplicate_records(adsl, exprs(USUBJID))
 extract_duplicate_records <- function(dataset, by_vars) {
-  assert_vars(by_vars)
-  assert_data_frame(dataset, required_vars = by_vars, check_is_grouped = FALSE)
+  assert_expr_list(by_vars)
+  assert_data_frame(dataset, required_vars = extract_vars(by_vars), check_is_grouped = FALSE)
 
   data_by <- dataset %>%
     ungroup() %>%
-    select(!!!by_vars)
+    # evaluate expressions in by_vars
+    transmute(!!!by_vars)
 
   is_duplicate <- duplicated(data_by) | duplicated(data_by, fromLast = TRUE)
 
   dataset %>%
     ungroup() %>%
-    select(!!!by_vars, dplyr::everything()) %>%
+    # evaluate expressions in by_vars
+    mutate(!!!by_vars) %>%
+    # move by variables to the beginning
+    # if by_vars includes unnamed expressions, the unevaluated expression is
+    # used as variable name
+    select(!!!syms(map(replace_values_by_names(by_vars), as_label)), everything()) %>%
     filter(is_duplicate) %>%
     arrange(!!!by_vars)
 }
@@ -73,8 +79,8 @@ extract_duplicate_records <- function(dataset, by_vars) {
 #' Signal Duplicate Records
 #'
 #' @param dataset A data frame
-#' @param by_vars A list of variables created using `exprs()` identifying groups of
-#'   records in which to look for duplicates
+#' @param by_vars A list of expressions created using `exprs()` identifying
+#'   groups of records in which to look for duplicates
 #' @param msg The condition message
 #' @param cnd_type Type of condition to signal when detecting duplicate records.
 #'   One of `"message"`, `"warning"` or `"error"`. Default is `"error"`.
@@ -94,10 +100,10 @@ extract_duplicate_records <- function(dataset, by_vars) {
 #' signal_duplicate_records(adsl, exprs(USUBJID), cnd_type = "message")
 signal_duplicate_records <- function(dataset,
                                      by_vars,
-                                     msg = paste("Dataset contains duplicate records with respect to", enumerate(vars2chr(by_vars))), # nolint
+                                     msg = paste("Dataset contains duplicate records with respect to", enumerate(replace_values_by_names(by_vars))), # nolint
                                      cnd_type = "error") {
-  assert_vars(by_vars)
-  assert_data_frame(dataset, required_vars = by_vars, check_is_grouped = FALSE)
+  assert_expr_list(by_vars)
+  assert_data_frame(dataset, required_vars = extract_vars(by_vars), check_is_grouped = FALSE)
   assert_character_scalar(msg)
   assert_character_scalar(cnd_type, values = c("message", "warning", "error"))
 
@@ -108,16 +114,28 @@ signal_duplicate_records <- function(dataset,
     admiral_environment$duplicates <- structure(
       duplicate_records,
       class = union("duplicates", class(duplicate_records)),
-      by_vars = vars2chr(by_vars)
+      by_vars = replace_values_by_names(by_vars)
     )
     full_msg <- paste0(msg, "\nRun `get_duplicates_dataset()` to access the duplicate records")
     cnd_funs[[cnd_type]](full_msg)
   }
 }
 
+#' Print `duplicates` Objects
+#'
+#' @param x A `duplicates` object
+#' @param ... Not used
+#'
+#' @return No return value, called for side effects
+#'
+#'
+#' @keywords utils_print
+#' @family utils_print
+#'
+#' @export
 print.duplicates <- function(x, ...) {
   cat(
-    "Dataset contains duplicate records with respect to ",
+    "Duplicate records with respect to ",
     enumerate(attr(x, "by_vars")),
     ".\n",
     sep = ""
