@@ -19,6 +19,8 @@ globalVariables(c(
   "AVAL",
   "AVALC",
   "AVALU",
+  "A1HI",
+  "A1LO",
   "BASE",
   "BASEC",
   "BASETYPE",
@@ -39,6 +41,7 @@ globalVariables(c(
   "ONTRTFL",
   "PARAMCD",
   "RANDDT",
+  "SOURCE",
   "STUDYID",
   "TRTDURD",
   "TRTEDT",
@@ -53,6 +56,7 @@ globalVariables(c(
   "USUBJID",
   "auto",
   "censor",
+  "check_nom",
   "data",
   "Dataset",
   "dataset_name",
@@ -73,11 +77,15 @@ globalVariables(c(
   "time_differential_dt",
   "tmp_obs_nr_filter_relative",
   "tmp_obs_nr_match_filter_relative",
-  "VAR_PREFIX",
-  "QUERY_NAME",
-  "QUERY_ID",
-  "QUERY_SCOPE",
-  "QUERY_SCOPE_NUM",
+  "PREFIX",
+  "PREFIX_CD",
+  "PREFIX_NAM",
+  "PREFIX_SC",
+  "PREFIX_SCN",
+  "GRPNAME",
+  "GRPID",
+  "SCOPE",
+  "SCOPEN",
   ".",
   "NAM",
   "CD",
@@ -115,9 +123,10 @@ globalVariables(c(
   "grpseq",
   "time_differential",
   "temp_flag",
-  "tmp_obs_nr_filter_confirmation",
-  "tmp_obs_nr_filter_confirmation.join",
+  "tmp_obs_nr_filter_joined",
+  "tmp_obs_nr_filter_joined.join",
   "tmp_obs_nr_var_conf_flag",
+  "tmp_obs_nr_var",
   "AGE",
   "SEX",
   "SMOKEFL",
@@ -134,7 +143,11 @@ globalVariables(c(
   "SI_UNIT_UPPER",
   "VAR_CHECK",
   "TERM",
+  "SRCVAR",
+  "TERMNAME",
+  "TERM_NAME_ID",
   "TERM_UPPER",
   "atoxgr_criteria_ctcv4",
-  "DTYPE"
+  "DTYPE",
+  "where" # this entry should be moved to @importFrom tidyselect once we use tidyselect 1.2.0
 ))
