@@ -1,6 +1,8 @@
 #' Open an ADaM Template Script
 #'
-#' @param adam_name An ADaM dataset name. You can use any of the available dataset name `r list_all_templates()`, and the dataset name is case-insensitive. The default dataset name is ADSL.
+#' @param adam_name An ADaM dataset name. You can use any of the available dataset name
+#' `r list_all_templates()`, and the dataset name is case-insensitive. The default dataset
+#' name is ADSL.
 #' @param save_path Path to save the script.
 #' @param package The R package in which to look for templates. By default `"admiral"`.
 #' @param overwrite Whether to overwrite an existing file named `save_path`.
@@ -8,7 +10,8 @@
 #'
 #' @return No return values, called for side effects
 #'
-#' @details Running without any arguments such as `use_ad_template()` auto-generates adsl.R in the current path. Use `list_all_templates()` to discover which templates are available.
+#' @details Running without any arguments such as `use_ad_template()` auto-generates adsl.R in
+#' the current path. Use `list_all_templates()` to discover which templates are available.
 #'
 #'
 #' @family utils_examples
@@ -61,7 +64,7 @@ use_ad_template <- function(adam_name = "adsl",
   }
 
   if (open) {
-    utils::file.edit(save_path)
+    file.edit(save_path)
   }
 
   invisible(TRUE)
@@ -85,7 +88,10 @@ list_all_templates <- function(package = "admiral") {
   assert_character_scalar(package)
 
   if (!requireNamespace(package, quietly = TRUE)) {
-    err_msg <- sprintf("No package called '%s' is installed and hence no templates are available", package)
+    err_msg <- sprintf(
+      "No package called '%s' is installed and hence no templates are available",
+      package
+    )
     abort(err_msg)
   }
 
