@@ -227,8 +227,8 @@ adeg <- adeg %>%
 ## Derive baseline flags ----
 adeg <- adeg %>%
   # Calculate BASETYPE
-  derive_var_basetype(
-    basetypes = rlang::exprs(
+  derive_basetype_records(
+    basetypes = exprs(
       "LAST: AFTER LYING DOWN FOR 5 MINUTES" = ATPTN == 815,
       "LAST: AFTER STANDING FOR 1 MINUTE" = ATPTN == 816,
       "LAST: AFTER STANDING FOR 3 MINUTES" = ATPTN == 817,
